Tutorials
=========

Many examples of using emiproc can be found in the folder 
examples from the github repository:

Examples 
--------

This folder contains guided and documented examples of how to use emiproc.

https://github.com/C2SM-RCM/emiproc/tree/master/examples 


Scripts 
-------

Scripts were create on some dedicated cases. They are not well documented
but there exist many for different cases. 

https://github.com/C2SM-RCM/emiproc/tree/master/scripts


Tutorials 
---------

Tutorials provide guided examples with more in depth of how to use emiproc.

The first tutorial to understand how emiproc works is the edgar_processing tutorial.

.. toctree::
    :maxdepth: 2

    edgar_processing
    gfed
    new_inventory
    icon_oem
    create_grid
